@@ -442,6 +442,8 @@ summarizeObserved <- function(df, to_predict = "event only",
            n0 = n0, d0 = d0, c0 = c0, r0 = r0, rp = rp,
            tp = tp, cutofftpdt = cutofftpdt,
            adsl = adsl, adtte = adtte,
+           cum_accrual_df = ad,
+           daily_accrual_df = enroll,
            event_km_df = kmdfEvent,
            dropout_km_df = kmdfDropout,
            cum_accrual_plot = cumAccrual,
@@ -452,8 +454,9 @@ summarizeObserved <- function(df, to_predict = "event only",
       list(trialsdt = trialsdt, cutoffdt = cutoffdt, t0 = t0,
            n0 = n0, d0 = d0, c0 = c0, r0 = r0, rp = rp,
            tp = tp, cutofftpdt = cutofftpdt,
-           adsl = adsl,
-           adtte = adtte, event_km_df = kmdfEvent,
+           adsl = adsl, adtte = adtte,
+           cum_accrual_df = ad,
+           event_km_df = kmdfEvent,
            dropout_km_df = kmdfDropout,
            cum_accrual_plot = cumAccrual,
            event_km_plot = kmEvent,
@@ -462,6 +465,8 @@ summarizeObserved <- function(df, to_predict = "event only",
   } else { # enrollment only
     list(trialsdt = trialsdt, cutoffdt = cutoffdt, t0 = t0,
          n0 = n0, adsl = adsl,
+         cum_accrual_df = ad,
+         daily_accrual_df = enroll,
          cum_accrual_plot = cumAccrual,
          daily_accrual_plot = dailyAccrual)
   }
